@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,5 +13,5 @@
 # limitations under the License.
 
 """
-Algorithms that performs calculations/heuristics on the outputs of `model`
+Algorithms that perform calculations/heuristics on the outputs of ``model``.
 """
