@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,33 +12,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""
-Counts the number of detected boxes
-"""
+"""Counts the number of detected boxes."""
 
-from typing import Dict, Any
+from typing import Any, Dict
 
-from peekingduck.pipeline.nodes.node import AbstractNode
+from peekingduck.pipeline.nodes.abstract_node import AbstractNode
 
 
 class Node(AbstractNode):
-    """Counting node class that counts total number of detected objects
+    """Counts the total number of detected objects.
 
     Inputs:
-        |bboxes|
+        |bboxes_data|
 
     Outputs:
-        |count|
+        |count_data|
 
     Configs:
-        None
+        None.
     """
 
     def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
         super().__init__(config, node_path=__name__, **kwargs)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
-        """Counts bboxes of object chosen in the frame. Note that this method
-        requires that the bbox returns all the same objects (for example, all people)
+        """Counts bboxes of object chosen in the frame.
+
+        Note that this method requires that the bboxes returned to all belong
+        to the same object category (for example, all "person").
         """
-        return {'count': len(inputs["bboxes"])}
+        return {"count": len(inputs["bboxes"])}
