@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,44 +13,44 @@
 # limitations under the License.
 
 """
-Estimates the 3D coordinates of an object given a 2D bounding box
+Estimates the 3D coordinates of an object given a 2D bounding box.
 """
 
-from typing import Dict, Any
+from typing import Any, Dict
+
 import numpy as np
-from peekingduck.pipeline.nodes.node import AbstractNode
+
+from peekingduck.pipeline.nodes.abstract_node import AbstractNode
 
 
 class Node(AbstractNode):
-    """Node that uses 2D bounding boxes information to estimate 3D location.
+    """Uses 2D bounding boxes information to estimate 3D location.
 
     Inputs:
-        |bboxes|
+        |bboxes_data|
 
     Outputs:
-        |obj_3D_locs|
+        |obj_3D_locs_data|
 
     Configs:
-        focal_length (:obj:`float`): **default = 1.14**
-
-            Approximate focal length of webcam used, in metres. Example on measuring focal length:
-            https://learnopencv.com/approximate-focal-length-for-webcams-and-cell-phone-cameras/
-
-
-        height_factor (:obj:`float`): **default = 2.5**
-
-            A factor used to estimate real-world distance from pixels, based on average human height
-            in metres. The value varies across different camera set-ups, and calibration may be
-            required.
+        focal_length (:obj:`float`): **default = 1.14**. |br|
+            Approximate focal length of webcam used, in metres. Example on
+            measuring focal length can be found `here <https://learnopencv.com
+            /approximate-focal-length-for-webcams-and-cell-phone-cameras/>`_.
+        height_factor (:obj:`float`): **default = 2.5**. |br|
+            A factor used to estimate real-world distance from pixels, based on
+            average human height in metres. The value varies across different
+            camera set-ups, and calibration may be required. Please refer to
+            the :ref:`Social Distancing use case
+            <use_case_social_distancing_using_object_detection>` for more
+            information.
     """
 
     def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
         super().__init__(config, node_path=__name__, **kwargs)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
-        """Converts 2D bounding boxes into 3D locations.
-        """
-
+        """Converts 2D bounding boxes into 3D locations."""
         locations = []
 
         for bbox in inputs["bboxes"]:
@@ -68,3 +68,7 @@ class Node(AbstractNode):
         outputs = {"obj_3D_locs": locations}
 
         return outputs
+
+    def _get_config_types(self) -> Dict[str, Any]:
+        """Returns dictionary mapping the node's config keys to respective types."""
+        return {"focal_length": float, "height_factor": float}
