@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,31 +13,27 @@
 # limitations under the License.
 
 
-"""
-Draws the lowest middle point of a bounding box.
-"""
+"""Draws the bottom middle point of a bounding box."""
 
 from typing import Any, Dict
 
 from peekingduck.pipeline.nodes.draw.utils.bbox import draw_pts
-from peekingduck.pipeline.nodes.node import AbstractNode
+from peekingduck.pipeline.nodes.abstract_node import AbstractNode
 
 
 class Node(AbstractNode):
-    """Draws the bottom middle point of detected bbounding boxes.
-
-    The ``draw.btm_midpoint`` node uses the ``bboxes`` from the model
-    predictions to draw the bbox predictions onto the image. For better
-    understanding of the usecase, refer to the
-    `zone counting usecase <use_cases/zone_counting.html>`_.
+    """The :mod:`draw.btm_midpoint` node uses :term:`bboxes` from the model
+    predictions to draw the bottom midpoint of each bbox as a dot onto the
+    image. For better understanding of the use case, refer to the
+    :doc:`Zone Counting use case </use_cases/zone_counting>`.
 
     Inputs:
-        |img|
+        |img_data|
 
-        |btm_midpoint|
+        |btm_midpoint_data|
 
     Outputs:
-        |none|
+        |none_output_data|
 
     Configs:
         None.
