@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,42 +13,53 @@
 # limitations under the License.
 
 """
-Draws detected groups and their tags.
+Draws large bounding boxes with tags, over identified groups of bounding boxes.
 """
 
 from typing import Any, Dict, List
 
 import numpy as np
 
+from peekingduck.pipeline.nodes.abstract_node import AbstractNode
 from peekingduck.pipeline.nodes.draw.utils.bbox import draw_bboxes, draw_tags
 from peekingduck.pipeline.nodes.draw.utils.constants import TOMATO
-from peekingduck.pipeline.nodes.node import AbstractNode
 
 
 class Node(AbstractNode):
-    """Draws large bounding boxes over multiple object bounding boxes which
-    have been identified as belonging to large groups.
+    """Draws large bounding boxes with tags over multiple object bounding boxes
+    which have been identified as belonging to the same group.
 
-    The ``draw.group_bbox_and_tag`` node uses the ``obj_groups`` and
-    ``large_groups`` from the ``dabble`` nodes to draw group bboxes and the
-    large group message tag onto the image. For better understanding, refer to
-    `group size checking usecase <use_cases/group_size_checking.html>`_.
+    The :term:`large_groups` data type from :mod:`dabble.check_large_groups`,
+    and the ``groups`` key of the :term:`obj_attrs` data type from
+    :mod:`dabble.group_nearby_objs`, are inputs for this node which identifies
+    the different groups, and the group associated with each bounding box.
+
+    For better understanding, refer to
+    the :doc:`Group Size Checking use case </use_cases/group_size_checking>`.
 
     Inputs:
-        |img|
+        |img_data|
 
-        |bboxes|
+        |bboxes_data|
 
-        |obj_groups|
+        |obj_attrs_data|
+        :mod:`draw.group_bbox_and_tag` requires the ``groups`` attribute from
+        :mod:`dabble.group_nearby_objs`.
 
-        |large_groups|
+        |large_groups_data|
 
     Outputs:
-        |none|
+        |none_output_data|
 
     Configs:
         tag (:obj:`str`): **default = "LARGE GROUP!"**. |br|
             The string message printed when a large group is detected.
+
+    .. versionchanged:: 1.2.0
+        :mod:`draw.group_bbox_and_tag` used to take in ``obj_tags``
+        (:obj:`List[str]`) as an input data type, which has been deprecated and
+        now subsumed under :term:`obj_attrs`. The same attribute is accessed by
+        using the ``groups`` key of :term:`obj_attrs`.
     """
 
     def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
@@ -59,14 +70,14 @@ class Node(AbstractNode):
         which have been identified as belonging to large groups.
 
         Args:
-            inputs (dict): Dictionary with keys "img", "bboxes", "obj_groups",
+            inputs (dict): Dictionary with keys "img", "bboxes", "obj_attrs",
                 "large_groups".
 
         Returns:
             outputs (dict): Dictionary with keys "none".
         """
         group_bboxes = self._get_group_bbox_coords(
-            inputs["large_groups"], inputs["bboxes"], inputs["obj_groups"]
+            inputs["large_groups"], inputs["bboxes"], inputs["obj_attrs"]["groups"]
         )
         group_tags = self._get_group_tags(inputs["large_groups"], self.tag)
 
@@ -76,6 +87,10 @@ class Node(AbstractNode):
 
         return {}
 
+    def _get_config_types(self) -> Dict[str, Any]:
+        """Returns dictionary mapping the node's config keys to respective types."""
+        return {"tag": str}
+
     @staticmethod
     def _get_group_bbox_coords(
         large_groups: List[int], bboxes: List[np.ndarray], obj_groups: List[int]
