@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,9 +13,7 @@
 # limitations under the License.
 
 
-"""
-functions for drawing bounding box related UI components
-"""
+"""Functions for drawing bounding box related UI components."""
 
 from typing import List, Tuple
 
@@ -32,7 +30,7 @@ from peekingduck.pipeline.nodes.draw.utils.constants import (
     PRIMARY_PALETTE,
 )
 from peekingduck.pipeline.nodes.draw.utils.constants import (
-    PRIMARY_PALETTE_LENGTH as TOTAL_COLOURS,
+    PRIMARY_PALETTE_LENGTH as TOTAL_COLORS,
 )
 from peekingduck.pipeline.nodes.draw.utils.constants import THICK, VERY_THICK
 from peekingduck.pipeline.nodes.draw.utils.general import (
@@ -46,60 +44,60 @@ def draw_bboxes(
     bboxes: List[List[float]],
     bbox_labels: List[str],
     show_labels: bool,
-    colour_choice: Tuple[int, int, int] = None,
+    color_choice: Tuple[int, int, int] = None,
 ) -> None:
-    """Draw bboxes onto an image frame.
+    """Draws bboxes onto an image frame.
 
     Args:
-        frame (np.array): image of current frame
-        bboxes (List[List[float]]): bounding box coordinates
-        colour (Tuple[int, int, int]): colour used for bounding box
-        bbox_labels (List[str]): labels of object detected
+        frame (np.ndarray): Image of current frame.
+        bboxes (List[List[float]]): Bounding box coordinates.
+        color (Tuple[int, int, int]): Color used for bounding box.
+        bbox_labels (List[str]): Labels of object detected.
     """
     image_size = get_image_size(frame)
-    # Get unique label colour indexes
-    colour_indx = {label: indx for indx, label in enumerate(set(bbox_labels))}
+    # Get unique label color indexes
+    color_idx = {label: idx for idx, label in enumerate(set(bbox_labels))}
 
     for i, bbox in enumerate(bboxes):
-        if colour_choice:
-            colour = colour_choice
+        if color_choice:
+            color = color_choice
         else:
-            colour = PRIMARY_PALETTE[colour_indx[bbox_labels[i]] % TOTAL_COLOURS]
+            color = PRIMARY_PALETTE[color_idx[bbox_labels[i]] % TOTAL_COLORS]
         if show_labels:
-            _draw_bbox(frame, bbox, image_size, colour, bbox_labels[i])
+            _draw_bbox(frame, bbox, image_size, color, bbox_labels[i])
         else:
-            _draw_bbox(frame, bbox, image_size, colour)
+            _draw_bbox(frame, bbox, image_size, color)
 
 
 def _draw_bbox(
     frame: np.ndarray,
-    bbox: List[float],
+    bbox: np.ndarray,
     image_size: Tuple[int, int],
-    colour: Tuple[int, int, int],
+    color: Tuple[int, int, int],
     bbox_label: str = None,
-) -> np.ndarray:
-    """Draw a single bounding box"""
+) -> None:
+    """Draws a single bounding box."""
     top_left, bottom_right = project_points_onto_original_image(bbox, image_size)
     cv2.rectangle(
         frame,
         (top_left[0], top_left[1]),
         (bottom_right[0], bottom_right[1]),
-        colour,
+        color,
         VERY_THICK,
     )
 
     if bbox_label:
-        _draw_label(frame, top_left, bbox_label, colour, BLACK)
+        _draw_label(frame, top_left, bbox_label, color, BLACK)
 
 
 def _draw_label(
     frame: np.ndarray,
     top_left: Tuple[int, int],
     bbox_label: str,
-    bg_colour: Tuple[int, int, int],
-    text_colour: Tuple[int, int, int],
+    bg_color: Tuple[int, int, int],
+    text_color: Tuple[int, int, int],
 ) -> None:
-    """Draw bbox label at top left of bbox"""
+    """Draws bbox label at top left of bbox."""
     # get label size
     (text_width, text_height), baseline = cv2.getTextSize(
         bbox_label, FONT_HERSHEY_SIMPLEX, NORMAL_FONTSCALE, THICK
@@ -108,8 +106,8 @@ def _draw_label(
     cv2.rectangle(
         frame,
         (top_left[0], top_left[1]),
-        (int(top_left[0] + text_width), int(top_left[1] - text_height - baseline)),
-        bg_colour,
+        (top_left[0] + text_width, top_left[1] - text_height - baseline),
+        bg_color,
         FILLED,
     )
 
@@ -118,10 +116,10 @@ def _draw_label(
     cv2.putText(
         frame,
         bbox_label,
-        (top_left[0], int(top_left[1] - 6)),
+        (top_left[0], top_left[1] - 6),
         FONT_HERSHEY_SIMPLEX,
         NORMAL_FONTSCALE,
-        text_colour,
+        text_color,
         THICK,
         LINE_AA,
     )
@@ -129,21 +127,21 @@ def _draw_label(
 
 def draw_tags(
     frame: np.ndarray,
-    bboxes: List[List[float]],
+    bboxes: np.ndarray,
     tags: List[str],
-    colour: Tuple[int, int, int],
+    color: Tuple[int, int, int],
 ) -> None:
     """Draw tags above bboxes.
 
     Args:
-        frame (np.array): image of current frame
-        bboxes (List[List[float]]): bounding box coordinates
-        tags (List[string]): tag associated with bounding box
-        color (Tuple[int, int, int]): color of text
+        frame (np.ndarray): Image of current frame.
+        bboxes (np.ndarray): Bounding box coordinates.
+        tags (Union[List[str], List[int]]): Tag associated with bounding box.
+        color (Tuple[int, int, int]): Color of text.
     """
     image_size = get_image_size(frame)
     for idx, bbox in enumerate(bboxes):
-        _draw_tag(frame, bbox, tags[idx], image_size, colour)
+        _draw_tag(frame, bbox, tags[idx], image_size, color)
 
 
 def _draw_tag(
@@ -151,9 +149,9 @@ def _draw_tag(
     bbox: np.ndarray,
     tag: str,
     image_size: Tuple[int, int],
-    colour: Tuple[int, int, int],
+    color: Tuple[int, int, int],
 ) -> None:
-    """Draw a tag above a single bounding box."""
+    """Draws a tag above a single bounding box."""
     top_left, btm_right = project_points_onto_original_image(bbox, image_size)
 
     # Find offset to centralize text
@@ -162,18 +160,19 @@ def _draw_tag(
     )
     bbox_width = btm_right[0] - top_left[0]
     offset = int((bbox_width - text_width) / 2)
-    position = (int(top_left[0] + offset), int(top_left[1] - baseline))
+    position = (top_left[0] + offset, top_left[1] - baseline)
+
     cv2.putText(
-        frame, tag, position, FONT_HERSHEY_SIMPLEX, NORMAL_FONTSCALE, colour, VERY_THICK
+        frame, tag, position, FONT_HERSHEY_SIMPLEX, NORMAL_FONTSCALE, color, VERY_THICK
     )
 
 
 def draw_pts(frame: np.ndarray, pts: List[Tuple[float]]) -> None:
-    """draw pts of selected object onto frame
+    """Draw pts of selected object onto frame.
 
     Args:
-        frame (np.array): image of current frame
-        pts (List[Tuple[float]]): bottom midpoints of bboxes
+        frame (np.array): Image of current frame.
+        pts (List[Tuple[float]]): Bottom midpoints of bboxes.
     """
     for point in pts:
         cv2.circle(frame, point, POINT_RADIUS, CHAMPAGNE, -1)
