@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,28 +13,29 @@
 # limitations under the License.
 
 """
-Draws the 2D boundaries of a zone
+Draws the 2D boundaries of a zone.
 """
 
 from typing import Any, Dict
-from peekingduck.pipeline.nodes.node import AbstractNode
+
 from peekingduck.pipeline.nodes.draw.utils.zone import draw_zones
+from peekingduck.pipeline.nodes.abstract_node import AbstractNode
 
 
 class Node(AbstractNode):
     """Draws the boundaries of each specified zone onto the image.
 
-    The draw zones node uses the zones from the zone_count dabble node to
-    draw a bounding box that represents the zone boundaries onto the image.
+    The ``draw.zones`` node uses the :term:`zones` output from the
+    ``dabble.zone_count`` node to draw a bounding box that represents the zone
+    boundaries onto the image.
 
     Inputs:
+        |img_data|
 
-        |img|
-
-        |zones|
+        |zones_data|
 
     Outputs:
-        |none|
+        |none_output_data|
 
     Configs:
         None.
@@ -47,10 +48,10 @@ class Node(AbstractNode):
         """Draws the boundaries of each specified zone onto the image.
 
         Args:
-            inputs (dict): Dict with keys "zones", "img".
+            inputs (dict): Dictionary with keys "zones", "img".
 
         Returns:
-            outputs (dict): Dict with keys "none".
+            outputs (dict): Dictionary with keys "none".
         """
 
         draw_zones(inputs["img"], inputs["zones"])  # type: ignore
