@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,14 +16,16 @@
 Reader functions for input nodes
 """
 
-from pathlib import Path
-from typing import Any, Tuple
-from threading import Thread, Event
 import logging
 import platform
 import queue
+from pathlib import Path
+from threading import Event, Thread
+from typing import Any, Tuple, Union
+
 import cv2
 
+from peekingduck.pipeline.nodes.input.utils.png_reader import PNGReader
 from peekingduck.pipeline.nodes.input.utils.preprocess import mirror
 
 
@@ -33,26 +35,25 @@ class VideoThread:
     """
 
     # pylint: disable=too-many-instance-attributes
-    # pylint: disable=logging-fstring-interpolation
 
     def __init__(
-        self, input_source: str, mirror_image: bool, buffer_frames: bool
+        self, input_source: Union[int, str], mirror_image: bool, buffering: bool
     ) -> None:
-        if platform.system().startswith("Windows"):
-            if str(input_source).isdigit():
-                # to eliminate opencv's "[WARN] terminating async callback"
+        assert isinstance(input_source, (int, str))
+        if isinstance(input_source, int):
+            if platform.system().startswith("Windows"):
+                # to eliminate opencv's "[WARN] terminating async callback" on Windows
                 self.stream = cv2.VideoCapture(input_source, cv2.CAP_DSHOW)
             else:
-                # no cv2.CAP_DSHOW flag if input_source is file
-                self.stream = cv2.VideoCapture(str(input_source))
+                self.stream = cv2.VideoCapture(input_source)
+        elif Path(input_source.lower()).suffix == ".png":
+            self.stream = PNGReader(input_source)
         else:
-            self.stream = cv2.VideoCapture(
-                str(input_source) if isinstance(input_source, Path) else input_source
-            )
-        self.logger = logging.getLogger("VideoThread")
-        self.mirror = mirror_image
+            self.stream = cv2.VideoCapture(input_source)
         if not self.stream.isOpened():
             raise ValueError(f"Camera or video input not detected: {input_source}")
+        self.logger = logging.getLogger(type(self).__name__)
+        self.mirror = mirror_image
         # events to coordinate threading
         self.is_done = Event()
         self.is_thread_start = Event()
@@ -60,7 +61,7 @@ class VideoThread:
         self.frame_counter = 0
         self.frame = None
         self.prev_frame = None
-        self.buffer = buffer_frames
+        self.buffer = buffering
         self.queue: queue.Queue = queue.Queue()
         # start threading
         self.thread = Thread(target=self._reading_thread, args=(), daemon=True)
@@ -91,7 +92,7 @@ class VideoThread:
             if self.stream.isOpened():
                 ret, frame = self.stream.read()
                 if not ret:
-                    self.logger.info(
+                    self.logger.debug(
                         f"_reading_thread: ret={ret}, "
                         f"#frames read={self.frame_counter}"
                     )
@@ -147,6 +148,15 @@ class VideoThread:
         num_frames = self.stream.get(cv2.CAP_PROP_FRAME_COUNT)
         return int(num_frames)
 
+    @property
+    def queue_size(self) -> int:
+        """Get buffer queue size
+
+        Returns:
+            int: number of frames in buffer
+        """
+        return self.queue.qsize()
+
     @property
     def resolution(self) -> Tuple[int, int]:
         """Get resolution of the camera device used.
@@ -165,26 +175,26 @@ class VideoNoThread:
     No threading to deal with recorded videos and images.
     """
 
-    def __init__(self, input_source: str, mirror_image: bool) -> None:
-        if platform.system().startswith("Windows"):
-            if str(input_source).isdigit():
-                # to eliminate opencv's "[WARN] terminating async callback"
+    def __init__(self, input_source: Union[int, str], mirror_image: bool) -> None:
+        assert isinstance(input_source, (int, str))
+        if isinstance(input_source, int):
+            if platform.system().startswith("Windows"):
+                # to eliminate opencv's "[WARN] terminating async callback" on Windows
                 self.stream = cv2.VideoCapture(input_source, cv2.CAP_DSHOW)
             else:
-                # no cv2.CAP_DSHOW flag if input_source is file
-                self.stream = cv2.VideoCapture(str(input_source))
+                self.stream = cv2.VideoCapture(input_source)
+        elif Path(input_source.lower()).suffix == ".png":
+            self.stream = PNGReader(input_source)
         else:
-            self.stream = cv2.VideoCapture(
-                str(input_source) if isinstance(input_source, Path) else input_source
-            )
-        self.logger = logging.getLogger("VideoNoThread")
-        self.mirror = mirror_image
+            self.stream = cv2.VideoCapture(input_source)
         if not self.stream.isOpened():
             raise ValueError(f"Video or image path incorrect: {input_source}")
         self._frame_counter = 0
+        self.logger = logging.getLogger(type(self).__name__)
+        self.mirror = mirror_image
 
     def __del__(self) -> None:
-        # dotw: self.logger.debug below crashes on Nvidia Jetson Xavier Ubuntu 18.04 python 3.6
+        # Note: self.logger.debug below crashes on Nvidia Jetson Xavier Ubuntu 18.04 python 3.6
         #       but does not crash on Intel MacBook Pro Ubuntu 20.04 python 3.7
         # self.logger.debug("VideoNoThread.__del__")
         self.stream.release()
@@ -195,7 +205,7 @@ class VideoNoThread:
         """
         ret, frame = self.stream.read()
         if not ret:
-            self.logger.info(
+            self.logger.debug(
                 f"read_frame: ret={ret}, #frames read={self._frame_counter}"
             )
         else:
@@ -231,6 +241,15 @@ class VideoNoThread:
         num_frames = self.stream.get(cv2.CAP_PROP_FRAME_COUNT)
         return int(num_frames)
 
+    @property
+    def queue_size(self) -> int:
+        """Get buffer queue size
+
+        Returns:
+            int: number of frames in buffer
+        """
+        return 0
+
     @property
     def resolution(self) -> Tuple[int, int]:
         """Get resolution of the file.
