@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 Preprocessing functions for PoseNet
 """
 
-from typing import Tuple
+from typing import Tuple, Union
 
 import cv2
 import numpy as np
@@ -29,9 +29,9 @@ from peekingduck.pipeline.nodes.model.posenetv1.posenet_files.constants import (
 def rescale_image(
     source_img: np.ndarray,
     input_res: Tuple[int, int],
-    scale_factor: float = 1.0,
-    output_stride: int = 16,
-    model_type: str = "mobilenet",
+    scale_factor: float,
+    output_stride: int,
+    model_type: Union[int, str],
 ) -> Tuple[np.ndarray, np.ndarray]:
     """Rescale the image by a scale factor while ensuring it has a valid output
     stride
@@ -44,7 +44,7 @@ def rescale_image(
         model_type (str): specified model type (refer to modelconfig.yml)
 
     Returns:
-        image_processed (np.array): proccessed image array
+        image_processed (np.array): processed image array
         scale (np.array): factor to scale height and width
     """
     target_width, target_height = _get_valid_resolution(
@@ -74,7 +74,10 @@ def _get_valid_resolution(
 
 
 def _rescale_image(
-    source_img: np.ndarray, target_width: int, target_height: int, model_type: str
+    source_img: np.ndarray,
+    target_width: int,
+    target_height: int,
+    model_type: Union[int, str],
 ) -> np.ndarray:
     """Apply different preprocessing depending on model type - mobilenet or resnet
 
@@ -84,6 +87,7 @@ def _rescale_image(
     image_processed = cv2.resize(
         source_img, (target_width, target_height), interpolation=cv2.INTER_LINEAR
     )
+    # Color conversion part of original repo code
     image_processed = cv2.cvtColor(image_processed, cv2.COLOR_BGR2RGB).astype(
         np.float32
     )
