@@ -1,4 +1,4 @@
-# Copyright 2021 AI Singapore
+# Copyright 2022 AI Singapore
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,42 +12,48 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""PoseNet model with model types: mobilenet50, mobilenet75, mobilenet100 and resnet"""
+"""PoseNet model with model types: mobilenet50, mobilenet75, mobilenet100 and
+resnet.
+"""
 
 import logging
-from typing import Dict, Any, Tuple
+from typing import Any, Dict, Tuple
+
 import numpy as np
 
-from peekingduck.weights_utils import checker, downloader
+from peekingduck.pipeline.nodes.base import (
+    ThresholdCheckerMixin,
+    WeightsDownloaderMixin,
+)
 from peekingduck.pipeline.nodes.model.posenetv1.posenet_files.predictor import Predictor
 
 
-class PoseNetModel:  # pylint: disable=too-few-public-methods
-    """PoseNet model with model types: mobilenet50, mobilenet75, mobilenet100 and resnet"""
+class PoseNetModel(ThresholdCheckerMixin, WeightsDownloaderMixin):
+    """PoseNet model with model types: mobilenet50, mobilenet75, mobilenet100
+    and resnet.
+    """
 
     def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__()
-
+        self.config = config
         self.logger = logging.getLogger(__name__)
 
-        # check threshold values
-        if not 0 <= config['score_threshold'] <= 1:
-            raise ValueError("score_threshold must be in [0, 1]")
-        if config['model_type'] not in [50, 75, 100, 'resnet']:
-            raise ValueError("model_type must be one of [50, 75, 100, resnet]")
+        self.check_valid_choice("model_type", {50, 75, 100, "resnet"})
+        self.check_bounds("score_threshold", "[0, 1]")
 
-        # check for posenet weights, if none then download into weights folder
-        if not checker.has_weights(config['root'],
-                                   config['weights_dir']):
-            print('---no posenet weights detected. proceeding to download...---')
-            downloader.download_weights(config['root'],
-                                        config['blob_file'])
-            print('---posenet weights download complete.---')
+        model_dir = self.download_weights()
+        self.predictor = Predictor(
+            model_dir,
+            self.config["model_type"],
+            self.weights["model_file"],
+            self.config["model_nodes"],
+            self.config["resolution"],
+            self.config["max_pose_detection"],
+            self.config["score_threshold"],
+        )
 
-        self.predictor = Predictor(config)
-
-    def predict(self, frame: np.ndarray) -> \
-            Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+    def predict(
+        self, frame: np.ndarray
+    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
         """ Predict poses from input frame
 
         Args:
